Name:           desmume
Version:        0.9.11
Release:        %mkrel 1
Summary:        A Nintendo DS emulator
Group:          Emulators
License:        GPLv2+
URL:            http://desmume.org/
Source0:        %{name}-%{version}.tar.xz
# Do not look into builddir (Fedora)
Patch0:         desmume-0.9-dontlookinbuilddir.patch
# Use system tinyxml instead of the embedded copy
Patch1:         desmume-0.9.11-tinyxml.patch
# Compile with gcc6
Patch2:         gcc6_fixes.patch
# Fix check for null terminator
Patch3:         desmume-0.9.11-null_terminator.patch

BuildRequires:  desktop-file-utils
BuildRequires:  intltool
BuildRequires:  %{_lib}gtkglext-devel
BuildRequires:  %{_lib}glade2.0_0-devel
BuildRequires:  %{_lib}lua5.2-devel
BuildRequires:  %{_lib}openal-devel
BuildRequires:  %{_lib}soundtouch-devel
BuildRequires:  %{_lib}zziplib-devel
BuildRequires:  %{_lib}tinyxml-devel

%description
DeSmuME is a Nintendo DS emulator running homebrew demos and commercial games.

#----------------------------------------------------------------------------

%package gtk
Summary:        A Nintendo DS emulator (Gtk GUI version)
Group:          Emulators
Provides:       %{name} = %{version}-%{release}

%description gtk
DeSmuME is a Nintendo DS emulator running homebrew demos and commercial games.

This is the GTK version.

%files gtk
%doc AUTHORS ChangeLog README README.LIN
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.*
%{_gamesbindir}/%{name}
%{_mandir}/man1/%{name}.1*

#----------------------------------------------------------------------------

%package glade
Summary:        A Nintendo DS emulator (Glade GUI version)
Group:          Emulators
Provides:       %{name} = %{version}-%{release}

%description glade
DeSmuME is a Nintendo DS emulator running homebrew demos and commercial games.

This is the GTK/Glade version.

%files glade -f %{name}-glade.lang
%doc AUTHORS ChangeLog README README.LIN
%{_datadir}/applications/%{name}-glade.desktop
%{_datadir}/pixmaps/%{name}-glade.*
%{_gamesbindir}/%{name}-glade
%{_gamesdatadir}/%{name}-glade/
%{_mandir}/man1/%{name}-glade.1*

#----------------------------------------------------------------------------

%package cli
Summary:        A Nintendo DS emulator (CLI version)
Group:          Emulators
Provides:       %{name} = %{version}-%{release}

%description cli
DeSmuME is a Nintendo DS emulator running homebrew demos and commercial games.

This is the CLI version.

%files cli
%doc AUTHORS ChangeLog README README.LIN
%{_gamesbindir}/%{name}-cli
%{_mandir}/man1/%{name}-cli.1*

#----------------------------------------------------------------------------

%prep
%setup -q
sed -i 's/\r//' src/MMU_timing.h
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

# Remove bundled tinyxml
rm -rf src/utils/tinyxml

# Fix end-of-line encoding
sed -i 's/\r//' AUTHORS

# Fix file encoding
for txtfile in ChangeLog AUTHORS
do
    iconv --from=ISO-8859-1 --to=UTF-8 $txtfile > tmp
    touch -r $txtfile tmp
    mv tmp $txtfile
done

# Fix glade path
sed -i 's|gladedir = $(datadir)/desmume/glade|gladedir = $(datadir)/games/desmume-glade/|g' src/gtk-glade/Makefile.{am,in}

# Fix gettext package name
sed -i 's|GETTEXT_PACKAGE=desmume|GETTEXT_PACKAGE=desmume-glade|g' configure{,.ac}

%build
%configure2_5x --bindir=%{_gamesbindir} \
               --enable-openal \
               --enable-glade
%make_build

%install
%make_install

# Rename installed icon and duplicate it for the glade package
pushd %{buildroot}%{_datadir}/pixmaps/
mv DeSmuME.xpm %{name}.xpm
cp %{name}.xpm %{name}-glade.xpm
popd

# Fix categories and icons of the desktop files
mkdir -p %{buildroot}%{_datadir}/applications
desktop-file-edit \
  --remove-category GNOME \
  --remove-category GTK \
  --set-icon %{name} \
  %{buildroot}%{_datadir}/applications/%{name}.desktop

desktop-file-edit \
  --remove-category GNOME \
  --remove-category GTK \
  --set-icon %{name}-glade \
  %{buildroot}%{_datadir}/applications/%{name}-glade.desktop

%find_lang %{name}-glade

%clean
rm -rf %{buildroot}
rm -rf $RPM_BUILD_DIR/%{name}-%{version}


%changelog

* Thu Sep 19 2019 Agent Smith <ruidobranco@yahoo.com.br> 0.9.11-1pclos2019
- Added patches from Fedora and Mageia
- Updated to the latest sources.

* Mon Jan 31 2011 Texstar <texstar at gmail.com> 0.9.6-2pclos2011
- remove old menu system not used anymore
- change specfile name to pclos-desmume.spec

* Thu Jan 27 2010 leiche <meisssw01 at aol.com> 0.9.6-1leiche2010
- update 0.9.6
- convert archive to tar.xz

* Sat Jan 02 2010 Leiche <MeissSW01 at aol.com> 0.9.5-1pclos2010
- 0.9.5

* Sun Oct 25 2009 Leiche <MeissSW01@aol.com> 0.9.2-1pclos2010
- update to 0.9.4 and rebuild for PCLinuxOS 2010

* Fri Apr 25 2008 P. K. Frederic <pkfric@yahoo.com> 0.8-1pclos2007
- first RPM for PCLinuxOS
- original spec file by Guillaume Bedot <littletux@zarb.org>

